@@ -14,7 +14,6 @@ import logging
 import os
 import os.path as op
 import shutil
-from collections import OrderedDict
 from operator import itemgetter
 from pathlib import Path
 from urllib.parse import urlparse
@@ -92,7 +91,6 @@ class ArchiveAnnexCustomRemote(AnnexCustomRemote):
     URL_SCHEME = SUPPORTED_SCHEMES[0]
     URL_PREFIX = URL_SCHEME + ":"
 
-    AVAILABILITY = "local"
     COST = 500
 
     def __init__(self, annex, path=None, persistent_cache=True, **kwargs):
@@ -141,7 +139,7 @@ class ArchiveAnnexCustomRemote(AnnexCustomRemote):
                     "Provide archive_file or archive_key - not both")
             archive_key = self.repo.get_file_annexinfo(archive_file)['key']
         assert(archive_key is not None)
-        attrs = OrderedDict()  # looking forward for more
+        attrs = dict()  # looking forward for more
         if file:
             attrs['path'] = file.lstrip('/')
         if size is not None:
